==> 9.1.2.zip: iClient-JavaScript-9.1.2/test/resources/spatialAnalystService.js <==
var bufferAnalysisByDatasetRecordNullResultJson = {
    "succeed": true,
    "recordset": null,
    "message": null
};
var bufferAnalysis_byDatasetResultJson = {
    "succeed": true,
    "recordset": {
        "features": [{
            "fieldNames": [
                "SmID",
                "SmSdriW"
            ],
            "geometry": {
                "center": {
                    "x": 4997.20338876219,
                    "y": -3357.69428403787
                },
                "parts": [
                    4
                ],
                "style": null,
                "prjCoordSys": null,
                "id": 1,
                "type": "REGION",
                "partTopo": [
                    1
                ],
                "points": [{
                    "x": 4964.01825038555,
                    "y": -3339.75627934742
                },
                    {
                        "x": 5008.09864202539,
                        "y": -3349.10666545284
                    },
                    {
                        "x": 4937.28581794784,
                        "y": -3328.20522829409
                    },
                    {
                        "x": 4964.01825038555,
                        "y": -3339.75627934742
                    }
                ]
            },
            "fieldValues": [
                "1",
                "4923.3193"
            ],
            "ID": 1
        }],
        "fieldCaptions": [
            "SmID",
            "SmSdriW",
        ],
        "fieldTypes": [
            "INT32",
            "SINGLE"
        ],
        "datasetName": null,
        "fields": [
            "SmID",
            "SmSdriW"
        ]
    },
    "message": null,
    "dataset": null
};
var bufferAnalysis_byGeometryResultJson = {
    "image": null,
    "resultGeometry": {
        "center": {
            "x": 6495.56158366533,
            "y": -4091.20088129942
        },
        "parts": [
            5
        ],
        "style": null,
        "prjCoordSys": null,
        "id": 0,
        "type": "REGION",
        "partTopo": [
            1
        ],
        "points": [{
            "x": 3282.46072425124,
            "y": -4440.22079458848
        },
            {
                "x": 3585.87383054393,
                "y": -3713.77444292663
            },
            {
                "x": 3593.10495680283,
                "y": -3698.02059884347
            },
            {
                "x": 2824.06039998604,
                "y": -4440.00002899231
            },
            {
                "x": 3282.46072425124,
                "y": -4440.22079458848
            }
        ]
    },
    "succeed": true,
    "message": null
};

var geometryBatchAnalystEscapedJson = [
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 117.50000000004,
                "y": 40.2500000204557
            },
            "parts": [
                4
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [
                {
                    "x": 118.000000322735,
                    "y": 40.0000003961772
                },
                {
                    "x": 118.000000463943,
                    "y": 40.0000002951589
                },
                {
                    "x": 118.000000554821,
                    "y": 40.0000001643381
                },
                {
                    "x": 118.000000322735,
                    "y": 40.0000003961772
                }
            ]
        },
        "succeed": true,
        "message": null
    }
];

var geometryBatchAnalystCommonResultJson = [
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 7884.79277012319,
                "y": 5072.18865322196
            },
            "parts": [
                4
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [{
                "x": 8184.79277012316,
                "y": 5072.18865322196
            },
                {
                    "x": 8127.49786843564,
                    "y": 4895.85307753422
                },
                {
                    "x": 7977.49786843564,
                    "y": 4786.87169833341
                },
                {
                    "x": 8184.79277012316,
                    "y": 5072.18865322196
                }
            ]
        },
        "succeed": true,
        "message": null
    },
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 170.3545301069,
                "y": 395.31795160385
            },
            "parts": [
                2
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "LINE",
            "partTopo": null,
            "points": [{
                "x": 170.3545301069,
                "y": 408.1485649972
            },
                {
                    "x": 170.3545301069,
                    "y": 382.4873382105
                }
            ]
        },
        "succeed": true,
        "message": null
    },
    {
        "succeed": true,
        "recordset": {
            "features": [{
                "fieldNames": [
                    "SmID"
                ],
                "geometry": {
                    "center": {
                        "x": -1816.90341987528,
                        "y": 2500
                    },
                    "parts": [
                        2
                    ],
                    "style": null,
                    "prjCoordSys": null,
                    "id": 1,
                    "type": "LINE",
                    "partTopo": null,
                    "points": [{
                        "x": -1402.35390301249,
                        "y": 1000
                    },
                        {
                            "x": -2231.45293673806,
                            "y": 4000
                        }
                    ]
                },
                "fieldValues": [
                    "1"
                ],
                "ID": 1
            }],
            "fieldCaptions": [
                "SmID"
            ],
            "fieldTypes": [
                "INT32"
            ],
            "datasetName": null,
            "fields": [
                "SmID"
            ]
        },
        "message": null,
        "dataset": null
    },
    {
        "succeed": true,
        "recordset": null,
        "message": null,
        "dataset": "Interpolation_IDWByGeo_commonTest_27@Interpolation"
    }
];

var geoRelationAnalystCommonResultJson = [{
    "result": [{
        "fieldNames": [
            "SMID",
            "NAME"
        ],
        "geometry": {
            "center": {
                "x": 4503.41060870386,
                "y": -3860.80113577829
            },
            "parts": [
                6
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 1,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [{
                "x": 52.1180504758377,
                "y": -55.5776523104111
            },
                {
                    "x": 8958.85087496886,
                    "y": -80.8510154881732
                },
                {
                    "x": 8951.6714818049,
                    "y": -7666.02461924617
                },
                {
                    "x": 52.1180504758377,
                    "y": -55.5776523104111
                }
            ]
        },
        "fieldValues": [
            "1",
            ""
        ],
        "ID": 1
    }],
    "count": 1,
    "source": {
        "fieldNames": [
            "SMID",
            "Y"
        ],
        "geometry": {
            "center": {
                "x": 4597.873059,
                "y": -4567.922216
            },
            "parts": [
                1
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 1,
            "type": "POINT",
            "partTopo": null,
            "points": [{
                "x": 4597.873059,
                "y": -4567.922216
            }]
        },
        "fieldValues": [
            "1",
            "-4567.922216"
        ],
        "ID": 1
    }
}
];

==> 11.1.1.zip: iClient-JavaScript-11.1.1/test/resources/spatialAnalystService.js <==
var bufferAnalysisByDatasetRecordNullResultJson = {
    "succeed": true,
    "recordset": null,
    "message": null
};
var bufferAnalysis_byDatasetResultJson = {
    "succeed": true,
    "recordset": {
        "features": [{
            "fieldNames": [
                "SmID",
                "SmSdriW"
            ],
            "geometry": {
                "center": {
                    "x": 4997.20338876219,
                    "y": -3357.69428403787
                },
                "parts": [
                    4
                ],
                "style": null,
                "prjCoordSys": null,
                "id": 1,
                "type": "REGION",
                "partTopo": [
                    1
                ],
                "points": [{
                    "x": 4964.01825038555,
                    "y": -3339.75627934742
                },
                    {
                        "x": 5008.09864202539,
                        "y": -3349.10666545284
                    },
                    {
                        "x": 4937.28581794784,
                        "y": -3328.20522829409
                    },
                    {
                        "x": 4964.01825038555,
                        "y": -3339.75627934742
                    }
                ]
            },
            "fieldValues": [
                "1",
                "4923.3193"
            ],
            "ID": 1
        }],
        "fieldCaptions": [
            "SmID",
            "SmSdriW",
        ],
        "fieldTypes": [
            "INT32",
            "SINGLE"
        ],
        "datasetName": null,
        "fields": [
            "SmID",
            "SmSdriW"
        ]
    },
    "message": null,
    "dataset": null
};
var bufferAnalysis_byGeometryResultJson = {
    "image": null,
    "resultGeometry": {
        "center": {
            "x": 6495.56158366533,
            "y": -4091.20088129942
        },
        "parts": [
            5
        ],
        "style": null,
        "prjCoordSys": null,
        "id": 0,
        "type": "REGION",
        "partTopo": [
            1
        ],
        "points": [{
            "x": 3282.46072425124,
            "y": -4440.22079458848
        },
            {
                "x": 3585.87383054393,
                "y": -3713.77444292663
            },
            {
                "x": 3593.10495680283,
                "y": -3698.02059884347
            },
            {
                "x": 2824.06039998604,
                "y": -4440.00002899231
            },
            {
                "x": 3282.46072425124,
                "y": -4440.22079458848
            }
        ]
    },
    "succeed": true,
    "message": null
};

var geometryBatchAnalystEscapedJson = [
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 117.50000000004,
                "y": 40.2500000204557
            },
            "parts": [
                4
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [
                {
                    "x": 118.000000322735,
                    "y": 40.0000003961772
                },
                {
                    "x": 118.000000463943,
                    "y": 40.0000002951589
                },
                {
                    "x": 118.000000554821,
                    "y": 40.0000001643381
                },
                {
                    "x": 118.000000322735,
                    "y": 40.0000003961772
                }
            ]
        },
        "succeed": true,
        "message": null
    }
];

var geometryBatchAnalystCommonResultJson = [
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 7884.79277012319,
                "y": 5072.18865322196
            },
            "parts": [
                4
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [{
                "x": 8184.79277012316,
                "y": 5072.18865322196
            },
                {
                    "x": 8127.49786843564,
                    "y": 4895.85307753422
                },
                {
                    "x": 7977.49786843564,
                    "y": 4786.87169833341
                },
                {
                    "x": 8184.79277012316,
                    "y": 5072.18865322196
                }
            ]
        },
        "succeed": true,
        "message": null
    },
    {
        "image": null,
        "resultGeometry": {
            "center": {
                "x": 170.3545301069,
                "y": 395.31795160385
            },
            "parts": [
                2
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 0,
            "type": "LINE",
            "partTopo": null,
            "points": [{
                "x": 170.3545301069,
                "y": 408.1485649972
            },
                {
                    "x": 170.3545301069,
                    "y": 382.4873382105
                }
            ]
        },
        "succeed": true,
        "message": null
    },
    {
        "succeed": true,
        "recordset": {
            "features": [{
                "fieldNames": [
                    "SmID"
                ],
                "geometry": {
                    "center": {
                        "x": -1816.90341987528,
                        "y": 2500
                    },
                    "parts": [
                        2
                    ],
                    "style": null,
                    "prjCoordSys": null,
                    "id": 1,
                    "type": "LINE",
                    "partTopo": null,
                    "points": [{
                        "x": -1402.35390301249,
                        "y": 1000
                    },
                        {
                            "x": -2231.45293673806,
                            "y": 4000
                        }
                    ]
                },
                "fieldValues": [
                    "1"
                ],
                "ID": 1
            }],
            "fieldCaptions": [
                "SmID"
            ],
            "fieldTypes": [
                "INT32"
            ],
            "datasetName": null,
            "fields": [
                "SmID"
            ]
        },
        "message": null,
        "dataset": null
    },
    {
        "succeed": true,
        "recordset": null,
        "message": null,
        "dataset": "Interpolation_IDWByGeo_commonTest_27@Interpolation"
    }
];

var geoRelationAnalystCommonResultJson = [{
    "result": [{
        "fieldNames": [
            "SMID",
            "NAME"
        ],
        "geometry": {
            "center": {
                "x": 4503.41060870386,
                "y": -3860.80113577829
            },
            "parts": [
                6
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 1,
            "type": "REGION",
            "partTopo": [
                1
            ],
            "points": [{
                "x": 52.1180504758377,
                "y": -55.5776523104111
            },
                {
                    "x": 8958.85087496886,
                    "y": -80.8510154881732
                },
                {
                    "x": 8951.6714818049,
                    "y": -7666.02461924617
                },
                {
                    "x": 52.1180504758377,
                    "y": -55.5776523104111
                }
            ]
        },
        "fieldValues": [
            "1",
            ""
        ],
        "ID": 1
    }],
    "count": 1,
    "source": {
        "fieldNames": [
            "SMID",
            "Y"
        ],
        "geometry": {
            "center": {
                "x": 4597.873059,
                "y": -4567.922216
            },
            "parts": [
                1
            ],
            "style": null,
            "prjCoordSys": null,
            "id": 1,
            "type": "POINT",
            "partTopo": null,
            "points": [{
                "x": 4597.873059,
                "y": -4567.922216
            }]
        },
        "fieldValues": [
            "1",
            "-4567.922216"
        ],
        "ID": 1
    }
}
];

var minDistanceAnalystEscapedJson = {
    "datasetName": null,
    "datasourceName": null,
    "distanceResults": [ 
      {
        "distance": 1941565.658677927,
        "referenceGeometryIDs": [465],
        "sourceGeometryID": 1
      },
      {
        "distance": 1941549.5697663245,
        "referenceGeometryIDs": [465],
        "sourceGeometryID": 2
      }
    ],
    "succeed": true,
    "message": null
  }
  

var getAreaSolarRadiationResultJson = {};
